@@ -25,10 +25,9 @@ impl Parse for Cluster {
                     .at(tree.id()));
                 }
             }
-
-            Ok(Cluster::Array(info, array_info))
+            Ok(info.array(array_info))
         } else {
-            Ok(Cluster::Single(info))
+            Ok(info.single())
         }
     }
 }
