@@ -162,6 +162,9 @@ mod fieldinfo;
 mod interrupt;
 mod modifiedwritevalues;
 mod peripheral;
+mod peripheralinfo;
+mod protection;
+mod readaction;
 mod register;
 mod registercluster;
 mod registerinfo;
@@ -200,6 +203,10 @@ pub enum SVDError {
     InvalidRegisterCluster(String),
     #[error("Invalid modifiedWriteValues variant, found {0}")]
     InvalidModifiedWriteValues(String),
+    #[error("Invalid readAction variant, found {0}")]
+    InvalidReadAction(String),
+    #[error("Invalid protection variant, found {0}")]
+    InvalidProtection(String),
     #[error("The content of the element could not be parsed to a boolean value {0}: {1}")]
     InvalidBooleanValue(String, core::str::ParseBoolError),
     #[error("dimIndex tag must contain {0} indexes, found {1}")]
